#ifndef __DUNE_MMDG_DGPROBLEM2_HH__
#define __DUNE_MMDG_DGPROBLEM2_HH__

#include <dune/mmdg/problems/dgproblem.hh>

template<class Coordinate, class Scalar = double>
class DGProblem2 : public DGProblem<Coordinate, Scalar>
{
  public:
    static constexpr int dim = Coordinate::dimension;
    using Base = DGProblem<Coordinate, Scalar>;
    using Matrix = typename Base::Matrix;

    //the exact solution at position pos
    //1d: p(x)     = x^2,
    //2d: p(x,y)   = x^2 + y^2,
    //3d: p(x,y,z) = x^2 + y^2 + z^2
    Scalar exactSolution (const Coordinate& pos) const
    {
      //return pos * Coordinate(1.0);
      return pos * pos;
    }

    //exact solution is implemented
    bool hasExactSolution() const
    {
      return true;
    };

    //source term at position pos
    Scalar q (const Coordinate& pos) const
    {
      return -2.0 * (dim + 3.0 * (pos * pos));
    }

    //permeability tensor at position pos
    Matrix K (const Coordinate& pos) const
    { //K = diag(1 + x_i^2 : i=1,...,dim)
      Matrix permeability(0.0);

      for (int i = 0; i < dim; i++)
      {
        permeability[i][i] = 1.0 + pos[i] * pos[i];
      }

      return permeability;
    }

    //returns the recommended quadrature order to compute an integral
    //over x * q(x)
    int quadratureOrder_q () const
    {
      return 2 * dim + 1;
    }

    //returns the recommended quadrature order to compute an integral
    //over x * boundary(x) and K(x) * boundary(x)
    int quadratureOrderBoundary () const
    {
      if constexpr (dim == 1)
      {
        return 2;
      }

      return 4;
    }

    //returns the recommended quadrature order to compute an integral
    //over an entry K[i][j] of the permeability tensor
    int quadratureOrder_K () const
    {
      return 2;
    }
};

#endif
