import numpy as np
import matplotlib.pyplot as plt
from mpltools.annotation import slope_marker
import matplotlib.pylab as pylab

params = {'legend.fontsize': 'x-large',
         'axes.labelsize': 'x-large',
         'axes.titlesize':'x-large',
         'xtick.labelsize':'x-large',
         'ytick.labelsize':'x-large'}
pylab.rcParams.update(params)

data_1d = np.loadtxt("plots/dgAnalysis_1d")
data_2d = np.loadtxt("plots/dgAnalysis_2d")
data_3d = np.loadtxt("plots/dgAnalysis_3d")

plt.loglog(np.reciprocal(data_1d[:,2]), data_1d[:,0], 'g^-', label='$n=1$')
plt.loglog(np.reciprocal(data_2d[:,2]), data_2d[:,0], 'bo-', label='$n=2$')
plt.loglog(np.reciprocal(data_3d[:,2]), data_3d[:,0], 'rs-', label='$n=3$')

x = 1.0 / data_3d[3,2]
y = 10 ** (0.2 * np.log10(data_3d[3,0]) + 0.8 * np.log10(data_3d[4,0]))
slope_marker((x, y), -2, size_frac = 0.15, invert = True, pad_frac = 0.12, \
    poly_kwargs={'ec': 'black', 'fill': False}, \
    text_kwargs={'size': 'x-large', 'text': '2', 'usetex': True})
plt.xlabel('$h^{-1}$')
plt.ylabel('$\Vert p - p_h \Vert_{L^2 ( \Omega )}$')
plt.legend()
plt.tight_layout()
plt.savefig('plots/dg.pdf', format='pdf')
